@@ -73,7 +73,7 @@ autostrat <- function(x,
   is.ichimoku(x) || stop("autostrat() only works on ichimoku objects", call. = FALSE)
   dir <- match.arg(dir)
   if (!level %in% 1:3) {
-    warning("Specified 'level' invalid - reverting to default of 1", call. = FALSE)
+    warning("'level' should be 1, 2 or 3 - reverting to default of 1", call. = FALSE)
     level <- 1
   }
 
