@@ -2,7 +2,7 @@ xtsobject <- ichimoku(sample_ohlc_data)[1:10, ]
 
 test_that("tradingDays ok", {
   expect_vector(tradingDays(as.POSIXct(c("2021-02-01", "2021-02-02", "2021-02-03"))), ptype = logical(), size = 3)
-#  expect_warning(expect_true(tradingDays(as.POSIXct("2021-02-02"), holidays = 0)), regexp = "holidays are invalid")
+  expect_warning(expect_true(tradingDays(as.POSIXct("2021-02-02"), holidays = "a")), regexp = "holidays are invalid")
   expect_true(all(tradingDays(as.POSIXct(c("2021-02-01", "2021-02-02", "2021-02-03")))))
   expect_true(all(tradingDays(as.POSIXct(c("2021-01-01", "2021-01-02")), holidays = NULL)))
   expect_false(all(tradingDays(as.POSIXct(c("2021-01-01", "2021-01-02", "2021-01-03")))))
